@@ -83,6 +83,10 @@
 #endif
 
 #if defined(_WIN32) && ! defined(__CYGWIN__)
+/* Declare POSIX-compatible names */
+#define _CRT_DECLARE_NONSTDC_NAMES 1
+/* Do not warn about POSIX name usage */
+#define _CRT_NONSTDC_NO_WARNINGS 1
 #ifndef _WIN32_WINNT
 #define _WIN32_WINNT 0x0501
 #else /* _WIN32_WINNT */
