@@ -80,6 +80,8 @@ test_simple_large ()
   connection.headers_received = &header;
   header.header = MHD_HTTP_HEADER_CONTENT_TYPE;
   header.value = MHD_HTTP_POST_ENCODING_FORM_URLENCODED;
+  header.header_size = strlen (header.header);
+  header.value_size = strlen (header.value);
   header.kind = MHD_HEADER_KIND;
   pp = MHD_create_post_processor (&connection, 1024, &value_checker, &pos);
   i = 0;
